@@ -18,7 +18,7 @@ def generate_pdf_from_string(html_content, output_path=None):
 def _generate_pdf_from_html(html, output_path=None):
     """Función interna para generar PDF desde HTML."""
     options = {
-        '--enable-local-file-access': None,
+        'enable-local-file-access': True,
         'page-size': 'Letter',
         'encoding': 'UTF-8',
         'margin-top': '1.5cm',
